@@ -11,6 +11,9 @@ from adblock.adblock import (
     OptimizedFilterExistence,
     BadFilterAddUnsupported,
     FilterExists,
+    AddResourceException,
+    InvalidUtf8ContentError,
+    InvalidBase64ContentError,
 )
 
 
@@ -26,4 +29,7 @@ __all__ = (
     "OptimizedFilterExistence",
     "BadFilterAddUnsupported",
     "FilterExists",
+    "AddResourceException",
+    "InvalidUtf8ContentError",
+    "InvalidBase64ContentError",
 )
